Cache class

Constructors

Cache(StorageClient storageClient, {required Duration duration})

Properties

duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T>({required String key, Duration? duration, required Future<T> process()}) → Future<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

init({String name = 'defaultCache', Duration duration = const Duration(hours: 1)}) → Future<Cache>