HttpClientMock class

Inheritance
Implemented types

Constructors

HttpClientMock()

Properties

apiUrl → String
finalinherited
connectTimeout → Duration?
finalinherited
enableLogs → bool
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
kIsWeb → bool
finalinherited
maxAttempts → int
finalinherited
preventLargeResponses → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkInternetConnection(List<Uri> urls) → Future<bool>
inherited
fetch({required String path, Map<String, dynamic>? params, Map<String, dynamic>? headers, int? maxAttempts, Cache? enableCache}) → Future<HttpResponse>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({required String path, required HttpMethod method, Object? data, Map<String, dynamic>? params, Map<String, dynamic>? headers, int? maxAttempts, Duration? timeout}) → Future<HttpResponse>
inherited
setHeader(String key, String? value) → bool
inherited
setHeaders(Map<String, String> map) → bool
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited