StorageClient class

Implementers

Constructors

StorageClient(Box storage)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getList(String key) → Future
getMap(String key) → Future
getString(String key) → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<void>
removeAll() → Future<int>
saveList(String key, List value) → Future<void>
saveMap(String key, Map value) → Future<void>
saveString(String key, String value) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

init({String name = 'defaultBox', required String path}) → Future<StorageClient>