StorageClientMock class

Inheritance
Implemented types

Constructors

StorageClientMock()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getList(String key) → Future
inherited
getMap(String key) → Future
inherited
getString(String key) → Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<void>
inherited
removeAll() → Future<int>
inherited
saveList(String key, List value) → Future<void>
inherited
saveMap(String key, Map value) → Future<void>
inherited
saveString(String key, String value) → Future<void>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited