Expectation<T> class

A captured method or property accessor -> a function that returns a value.

Constructors

Expectation(Matcher call, Answer<T> response)
A captured method or property accessor -> a function that returns a value.
const
Expectation.allInvocations(Answer<T> response)
A captured method or property accessor -> a function that returns a value.
const

Properties

call → Matcher
A captured method or property accessor.
final
hashCode → int
The hash code for this object.
no setterinherited
response → Answer<T>
Result function that should be invoked.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited