framework
library
Constants
alwaysThrows
→ const Object
Annotation marking a function as always throwing.
awaitNotRequired
→ const Object
Annotation on asynchronous function whose Future can be ignored.
checked
→ const Object
Annotation that no longer has any effect.
doNotStore
→ const Object
Annotation on function or property whose value must not be stored.
doNotSubmit
→ const Object
Annotation marking declaration that should be removed before publishing.
experimental
→ const Object
Annotation marking declaration as experimental and subject to change.
factory
→ const Object
Annotation on a function that creates new objects.
freezed
→ const Freezed
Defines an immutable data-class.
immutable
→ const Immutable
Annotation on an immutable class.
internal
→ const Object
Annotation on declaration that should not be used outside of its package.
isTest
→ const Object
Annotation on a test framework function that introduces a single test.
isTestGroup
→ const Object
Annotation on a test framework function that introduces a group of tests.
literal
→ const Object
Annotation on constructor that must be invoked with const if possible.
mustBeConst
→ const Object
Annotation on a parameter whose arguments must be constants.
mustBeOverridden
→ const Object
Annotation on instance members that must be overridden by subclasses.
mustCallSuper
→ const Object
Annotation on instance member that overriding members must call.
nonVirtual
→ const Object
Annotation on instance member that must not be overridden.
optionalTypeArgs
→ const Object
Annotation on type arguments that can safely be omitted.
protected
→ const Object
Annotation on instance member that should only be used by subclasses.
redeclare
→ const Object
Annotation on extension type members which redeclare superinterface members.
reopen
→ const Object
Annotation on declaration with less access restrictions than superinterface.
required
→ const Required
Annotation on named parameter that should always have an argument supplied.
sealed
→ const Object
Annotation on class that must not be subclassed outside of its package.
unfreezed
→ const Freezed
Defines a potentially mutable data-class.
useResult
→ const UseResult
Annotation on function or property whose value must not be ignored.
virtual
→ const Object
Annotation which no longer has any effect.
visibleForOverriding
→ const Object
Annotation on declaration that should not be used outside of its package.
visibleForTesting
→ const Object
Annotation on a public declaration that should only be used in tests.
Properties
logger
→ Logger
final
untilCalled
→ Future <Invocation > Function<T >(T _ () )
Returns a future Invocation that will complete upon the first occurrence
of the given invocation.
no setter
verify
→ Verify
Verify that a method on a mock object was called with the given arguments.
no setter
verifyInOrder
→ List <VerificationResult > Function<T >(List <T Function() > recordedInvocations )
Verifies that a list of methods on a mock object have been called with the
given arguments. For example:
no setter
verifyNever
→ Verify
Verify that a method on a mock object was never called with the given
arguments.
no setter
when
→ When <T > Function<T >(T x () )
Create a stub method response.
no setter
Functions
$checkedConvert <T > (Map map , String key , T castFunc (dynamic ), {Object ? readValue (Map , String )? })
→ T
Helper function used in generated code when
JsonSerializableGenerator.checked is true.
$checkedCreate <T > (String className , Map map , T constructor (S <S >(String , S (Object ? ), {Object ? readValue (Map , String )? }) ), {Map <String , String > fieldKeyMap = const {} })
→ T
Helper function used in generated code when
JsonSerializableGenerator.checked is true.
$checkedNew <T > (String className , Map map , T constructor (), {Map <String , String > ? fieldKeyMap })
→ T
Helper function used in generated code when
JsonSerializableGenerator.checked is true.
$checkKeys (Map map , {List <String > ? allowedKeys , List <String > ? requiredKeys , List <String > ? disallowNullValues })
→ void
Helper function used in generated fromJson code when
JsonSerializable.disallowUnrecognizedKeys is true for an annotated type or
JsonKey.required is true for any annotated fields.
$enumDecode <K extends Enum , V > (Map <K , V > enumValues , Object ? source , {K? unknownValue })
→ K
Returns the key associated with value source from enumValues, if one
exists.
$enumDecodeNullable <K extends Enum , V > (Map <K , V > enumValues , Object ? source , {Enum ? unknownValue })
→ K?
Returns the key associated with value source from enumValues, if one
exists.
any <T > ({String ? named , Matcher? that })
→ T
An argument matcher that matches any argument passed in.
captureAny <T > ({String ? named , Matcher? that })
→ T
An argument matcher that captures any argument passed in.
clearInteractions (dynamic mock )
→ void
Clear the collected interactions with mock.
logInvocations (List <Mock > mocks )
→ void
Print all collected invocations of any mock methods of mocks.
nanoid ({int length = 21 , String ? alphabet , Random ? random })
→ String
This generator function create a tiny, secure, URL-friendly, unique string ID
registerFallbackValue (dynamic value )
→ void
Allows any and captureAny to be used on parameters of type value.
reset (dynamic mock )
→ void
Clear stubs of, and collected interactions with mock.
resetMocktailState ()
→ void
Reset the state of Mocktail, typically for use between tests.
sandbox (Function function , {LogLevel logLevel = LogLevel.debug , bool enableStopwatch = true })
→ Future <void >
throwOnMissingStub (Mock mock , {void exceptionBuilder (Invocation )? })
→ void
Opt-into Mock throwing NoSuchMethodError for unimplemented methods.
verifyNoMoreInteractions (dynamic mock )
→ void
Ensure no redundant invocations occur.
verifyZeroInteractions (dynamic mock )
→ void
Ensure interactions never happened on a mock.
Typedefs
Answer <T >
= T Function(Invocation invocation )
Returns a value dependent on the details of an invocation.
Verify
= VerificationResult Function<T >(T matchingInvocations () )
Type definition for the object returned when invoking verify .